@@ -1,8 +1,3 @@
-"""
-This file defined the Stratum class for confined optical mode in 1D using
-transfer matrix method
-"""
-
 import numpy as np
 from numpy import sqrt, exp, pi, sin, cos, sinc
 from .Material import rIdx, MParam
@@ -32,21 +27,21 @@ class MaxwellLayer(object):
 
     Parameters
     ----------
-    wl : float
+    wl :
         Wavelength in vacuum to guide in the stratum
 
-    indices : list(complex)
+    indices :
         The Refractive indices of the layers except for the top and the
         substrate. The substrate and the top layer is not part of the list
         because they decides the boundary condition for the solver.
 
-    index0 : complex
+    index0 :
         The refractive index for the top layer
 
-    indexS : complex
+    indexS :
         The refractive index for the substrate layer
 
-    Ls : list(float)
+    Ls :
         Thickness of the stratum, same unit as wl. The first and last elements
         are for top and substrate and is not used for calculation
     """
@@ -414,22 +409,27 @@ class OptStrata(MaxwellLayer):
         the gain coefficient. The variable is only for book keeping and is
         not used for any calculation.
     """
-    def __init__(self, wl=3.0, materials=['Air', 'InP'], moleFracs=[0.0, 0.0],
-                 dopings=[0.0, 0.0], Ls=[1.0, 1.0], mobilities=None,
+    def __init__(self, wl=3.0, materials=['Air', 'InP'], moleFracs=None,
+                 dopings=None, Ls=[1.0, 1.0], mobilities=None,
                  cstmIndx=dict(), cstmPrd=defaultdict(float),
                  cstmGain=defaultdict(float)):
         super(OptStrata, self).__init__(wl)
+        N = len(materials)
         self.materials = list(AlloyNick[m] if m in AlloyNick else m
                               for m in materials)
-        self.moleFracs = list(moleFracs)
-        self.dopings = list(dopings)
+        self.moleFracs = list(moleFracs) if moleFracs else [0.0] * N
+        self.dopings = list(dopings) if dopings else [0.0] * N
         self.Ls = (np.array(Ls) if len(Ls) == len(materials)
                    else np.array([1.0] + list(Ls) + [2.0]))
         self.mobilities = ([None]*len(materials)
                            if mobilities is None else mobilities)
+        assert len(self.moleFracs) == N
+        assert len(self.dopings) == N
+        assert len(self.Ls) == N
         self.cstmIndx = cstmIndx
         self.cstmPrd = cstmPrd
         self.cstmGain = cstmGain
+        self.updateIndices()
 
     def __str__(self):
         return "\n".join(("wavelength: %f" % self.wl,
@@ -628,5 +628,3 @@ def optimizeOptStrata(stratum: OptStrata, alphaM,
             break
         penalty *= 2
     print('Finished with penalty: ', penalty)
-
-# vim: ts=4 sw=4 sts=4 expandtab
